pub struct WasmModuleManager { /* private fields */ }Implementations
Sourceimpl WasmModuleManager
impl WasmModuleManager
pub fn new(config: WasmRuntimeConfig) -> Self
pub fn with_default_config() -> Self
Sourcepub fn register_module_internal(&self, module: WasmModule) -> Result<()>
pub fn register_module_internal(&self, module: WasmModule) -> Result<()>
Register a module (for workflow steps)
Sourcepub fn remove_module_internal(&self, module_uuid: Uuid) -> Result<()>
pub fn remove_module_internal(&self, module_uuid: Uuid) -> Result<()>
Remove a module (for workflow steps)
pub fn check_duplicate_sha256_hash(&self, sha256_hash: &[u8; 32]) -> Result<()>
pub fn get_all_modules(&self) -> Result<Vec<WasmModule>>
pub fn get_module(&self, module_uuid: Uuid) -> Result<Option<WasmModule>>
pub fn get_modules(&self) -> Result<Vec<WasmModule>>
Sourcepub fn get_modules_by_attach_point(
&self,
attach_point: WasmModuleAttachPoint,
) -> Result<Vec<WasmModule>>
pub fn get_modules_by_attach_point( &self, attach_point: WasmModuleAttachPoint, ) -> Result<Vec<WasmModule>>
get modules by attach point
pub fn get_runtime(&self) -> &Arc<WasmRuntime>
Sourcepub fn get_max_body_size(&self) -> usize
pub fn get_max_body_size(&self) -> usize
Get the configured maximum body size for HTTP request/response processing
Sourcepub async fn execute_module_interface(
&self,
module_uuid: Uuid,
attach_point: WasmModuleAttachPoint,
input: WasmComponentInput,
) -> Result<WasmComponentOutput>
pub async fn execute_module_interface( &self, module_uuid: Uuid, attach_point: WasmModuleAttachPoint, input: WasmComponentInput, ) -> Result<WasmComponentOutput>
Execute WASM module using WebAssembly component model based on attach_point
Sourcepub fn execute_module_interface_sync(
&self,
module_uuid: Uuid,
attach_point: WasmModuleAttachPoint,
input: WasmComponentInput,
) -> Result<WasmComponentOutput>
pub fn execute_module_interface_sync( &self, module_uuid: Uuid, attach_point: WasmModuleAttachPoint, input: WasmComponentInput, ) -> Result<WasmComponentOutput>
Execute WASM module using WebAssembly component model (sync version)
Sourcepub async fn execute_module_for_attach_point(
&self,
module: &WasmModule,
attach_point: WasmModuleAttachPoint,
input: WasmComponentInput,
) -> Option<MiddlewareAction>
pub async fn execute_module_for_attach_point( &self, module: &WasmModule, attach_point: WasmModuleAttachPoint, input: WasmComponentInput, ) -> Option<MiddlewareAction>
Execute a WASM module for a given attach point Returns the Action if successful, or None if execution failed
This is a convenience method that wraps execute_module_interface and handles error logging automatically.